import { ElementRef, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import type { ChartConfiguration, ChartData, InteractionItem, Plugin } from 'chart.js';
import { Chart as ChartJS } from 'chart.js';
import { BooleanInput } from './chartjs.interface';
import * as i0 from "@angular/core";
export declare class ChartjsComponent implements OnDestroy, OnChanges {
    static ngAcceptInputType_redraw: BooleanInput;
    private readonly ngZone;
    private readonly renderer;
    private readonly changeDetectorRef;
    /**
     * Enables custom html based tooltips instead of standard tooltips.
     * @return boolean
     * @default true
     */
    readonly customTooltips: import("@angular/core").InputSignalWithTransform<boolean, unknown>;
    /**
     * The data object that is passed into the Chart.js chart (more info).
     */
    readonly data: import("@angular/core").InputSignal<ChartData<keyof import("chart.js").ChartTypeRegistry, (number | [number, number] | import("chart.js").Point | import("chart.js").BubbleDataPoint | null)[], unknown> | undefined>;
    /**
     * A fallback when the canvas cannot be rendered. Can be used for accessible chart descriptions.
     */
    /**
     * Height attribute applied to the rendered canvas.
     * @return number | undefined
     * @default null
     */
    readonly height: import("@angular/core").InputSignalWithTransform<number | null, unknown>;
    /**
     * ID attribute applied to the rendered canvas.
     * @return string
     */
    readonly idInput: import("@angular/core").InputSignal<string>;
    get id(): string;
    /**
     * The options object that is passed into the Chart.js chart.
     */
    readonly optionsInput: import("@angular/core").InputSignal<import("node_modules/chart.js/dist/types/utils")._DeepPartialObject<import("chart.js").CoreChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").ElementChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").PluginChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").DatasetChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").ScaleChartOptions<keyof import("chart.js").ChartTypeRegistry>> | undefined>;
    readonly options: import("@angular/core").WritableSignal<import("node_modules/chart.js/dist/types/utils")._DeepPartialObject<import("chart.js").CoreChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").ElementChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").PluginChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").DatasetChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").ScaleChartOptions<keyof import("chart.js").ChartTypeRegistry>> | undefined>;
    /**
     * The plugins array that is passed into the Chart.js chart
     */
    readonly plugins: import("@angular/core").InputSignal<Plugin<keyof import("chart.js").ChartTypeRegistry, import("node_modules/chart.js/dist/types/basic").AnyObject>[]>;
    /**
     * If true, will tear down and redraw chart on all updates.
     * @return boolean
     * @default false
     */
    readonly redraw: import("@angular/core").InputSignalWithTransform<boolean, unknown>;
    /**
     * Chart.js chart type.
     * @return {'line' | 'bar' | 'radar' | 'doughnut' | 'polarArea' | 'bubble' | 'pie' | 'scatter'}
     */
    readonly type: import("@angular/core").InputSignal<keyof import("chart.js").ChartTypeRegistry>;
    /**
     * Width attribute applied to the rendered canvas.
     * @return number | undefined
     * @default null
     */
    readonly width: import("@angular/core").InputSignalWithTransform<number | null, unknown>;
    /**
     * Put the chart into the wrapper div element.
     * @default true
     */
    readonly wrapper: import("@angular/core").InputSignalWithTransform<boolean, unknown>;
    readonly getDatasetAtEvent: import("@angular/core").OutputEmitterRef<InteractionItem[]>;
    readonly getElementAtEvent: import("@angular/core").OutputEmitterRef<InteractionItem[]>;
    readonly getElementsAtEvent: import("@angular/core").OutputEmitterRef<InteractionItem[]>;
    readonly chartRef: import("@angular/core").OutputEmitterRef<any>;
    readonly canvasElement: import("@angular/core").Signal<ElementRef<any>>;
    chart: ChartJS;
    ctx: CanvasRenderingContext2D;
    readonly hostClasses: import("@angular/core").Signal<{
        'chart-wrapper': boolean;
    }>;
    constructor();
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    handleClick($event: MouseEvent): void;
    chartDestroy(): void;
    chartRender(): void;
    chartUpdate(): void;
    private chartUpdateOutsideAngular;
    chartToBase64Image(): string | undefined;
    private chartDataConfig;
    readonly chartOptions: import("@angular/core").Signal<import("node_modules/chart.js/dist/types/utils")._DeepPartialObject<import("chart.js").CoreChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").ElementChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").PluginChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").DatasetChartOptions<keyof import("chart.js").ChartTypeRegistry> & import("chart.js").ScaleChartOptions<keyof import("chart.js").ChartTypeRegistry>>>;
    readonly chartConfig: import("@angular/core").Signal<ChartConfiguration<keyof import("chart.js").ChartTypeRegistry, (number | [number, number] | import("chart.js").Point | import("chart.js").BubbleDataPoint | null)[], unknown>>;
    private chartCustomTooltips;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChartjsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChartjsComponent, "c-chart", ["cChart"], { "customTooltips": { "alias": "customTooltips"; "required": false; "isSignal": true; }; "data": { "alias": "data"; "required": false; "isSignal": true; }; "height": { "alias": "height"; "required": false; "isSignal": true; }; "idInput": { "alias": "id"; "required": false; "isSignal": true; }; "optionsInput": { "alias": "options"; "required": false; "isSignal": true; }; "plugins": { "alias": "plugins"; "required": false; "isSignal": true; }; "redraw": { "alias": "redraw"; "required": false; "isSignal": true; }; "type": { "alias": "type"; "required": false; "isSignal": true; }; "width": { "alias": "width"; "required": false; "isSignal": true; }; "wrapper": { "alias": "wrapper"; "required": false; "isSignal": true; }; }, { "getDatasetAtEvent": "getDatasetAtEvent"; "getElementAtEvent": "getElementAtEvent"; "getElementsAtEvent": "getElementsAtEvent"; "chartRef": "chartRef"; }, never, ["*"], true, never>;
}
